==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/ca.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "La configuració s'ha actualitzat.",
"Activity" => "Activitat",
"A file or folder has been <strong>shared</strong>" => "S'ha <strong>compartit</strong> un fitxer o una carpeta",
"A new file or folder has been <strong>created</strong> in a shared folder" => "S'ha <strong>creat</strong> un fitxer o una carpeta nous en una carpeta compartida",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Ha <strong>canviat</strong> un fitxer o una carpeta en una carpeta compartida",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "S'ha <strong>eliminat</strong> un fitxer o una carpeta d'una carpeta en una carpeta compartida",
"You created %1\$s" => "Has creat %1\$s",
"%2\$s created %1\$s" => "%2\$s ha creat %1\$s",
"You changed %1\$s" => "Has canviat %1\$s",
"%2\$s changed %1\$s" => "%2\$s ha canviat %1\$s",
"You deleted %1\$s" => "Has esborrat %1\$s",
"%2\$s deleted %1\$s" => "%2\$s ha esborrat %1\$s",
"You shared %1\$s with %2\$s" => "Has compartit %1\$s amb %2\$s",
"You shared %1\$s with group %2\$s" => "has compartit %1\$s amb el grup %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s ha compartit %1\$s amb tu",
"Activity notification" => "Notificació d'activitat",
"All Activities" => "Totes les activitats",
"Activities by you" => "Activitats vostres",
"Activities by others" => "Activitats dels altres",
"Shares" => "Compartits",
"Files" => "Fitxers",
"%s and %s" => "%s i %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s i <strong class=\"tooltip\" title=\"%s\">%n més</strong>","%s i <strong class=\"tooltip\" title=\"%s\">%n més</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s i %n més","%s i %n més"),
"Hello %s," => "Hola %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Esteu rebent aquest correu perquè en l'última hora han succeït les següents coses a %s",
"You are receiving this email because in the last day the following things happened at %s" => "Esteu rebent aquest correu perquè en l'últim dia han succeït les següents coses a %s",
"You are receiving this email because in the last week the following things happened at %s" => "Esteu rebent aquest correu perquè en l'última setmana han succeït les següents coses a %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Quan comenceu a usar %s veureu una llista de successos aquí.",
"No more events to load" => "No hi ha més elements a carregar",
"Enable RSS feed" => "Activa l'alimentació RSS",
"Notifications" => "Notificacions",
"Mail" => "Correu electrónic",
"Stream" => "Cadena",
"You need to set up your email address before you can receive notification emails." => "Heu d'establir l'adreça de correu electrònic abans que pugueu rebre correus de notificació",
"Send emails:" => "Envia correus electrònics:",
"Hourly" => "Horàriament",
"Daily" => "Diari",
"Weekly" => "Mensual",
"Activity feed" => "Llista d'activitat",
"Personal activity feed for %s" => "Llista d'activitat personal per a %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.3~~20141010%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/ca.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "La configuració s'ha actualitzat.",
"Activity" => "Activitat",
"A file or folder has been <strong>shared</strong>" => "S'ha <strong>compartit</strong> un fitxer o una carpeta",
"A new file or folder has been <strong>created</strong>" => "S'ha <strong>creat</strong> un nou fitxer o una nova carpeta",
"A file or folder has been <strong>changed</strong>" => "S'ha <strong>canviat</strong> un fitxer o una carpeta",
"A file or folder has been <strong>deleted</strong>" => "S'ha <strong>elminiat</strong> un fitxer o una carpeta",
"You created %1\$s" => "Has creat %1\$s",
"%2\$s created %1\$s" => "%2\$s ha creat %1\$s",
"%1\$s was created in a public folder" => "Es va crear %1\$s en una carpeta pública",
"You changed %1\$s" => "Has canviat %1\$s",
"%2\$s changed %1\$s" => "%2\$s ha canviat %1\$s",
"You deleted %1\$s" => "Has esborrat %1\$s",
"%2\$s deleted %1\$s" => "%2\$s ha esborrat %1\$s",
"You shared %1\$s with %2\$s" => "Has compartit %1\$s amb %2\$s",
"You shared %1\$s with group %2\$s" => "has compartit %1\$s amb el grup %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s ha compartit %1\$s amb tu",
"You shared %1\$s via link" => "Heu compartit %1\$s via enllaç",
"Activity notification" => "Notificació d'activitat",
"All Activities" => "Totes les activitats",
"Activities by you" => "Les teves activitats",
"Activities by others" => "Activitats dels altres",
"Shares" => "Compartits",
"Files" => "Fitxers",
"in %s" => "en %s",
"%s and %s" => "%s i %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s i <strong class=\"tooltip\" title=\"%s\">%n més</strong>","%s i <strong class=\"tooltip\" title=\"%s\">%n més</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s i %n més","%s i %n més"),
"Hello %s," => "Hola %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Esteu rebent aquest correu perquè en l'última hora han succeït les següents coses a %s",
"You are receiving this email because in the last day the following things happened at %s" => "Esteu rebent aquest correu perquè en l'últim dia han succeït les següents coses a %s",
"You are receiving this email because in the last week the following things happened at %s" => "Esteu rebent aquest correu perquè en l'última setmana han succeït les següents coses a %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Quan comenceu a usar %s veureu una llista de successos aquí.",
"No more events to load" => "No hi ha més elements a carregar",
"Enable RSS feed" => "Activa l'alimentació RSS",
"Notifications" => "Notificacions",
"Mail" => "Correu electrónic",
"Stream" => "Cadena",
"Notify about my own actions" => "Notifica'm les meves accions",
"You need to set up your email address before you can receive notification emails." => "Heu d'establir l'adreça de correu electrònic abans que pugueu rebre correus de notificació",
"Send emails:" => "Envia correus electrònics:",
"Hourly" => "Horàriament",
"Daily" => "Diari",
"Weekly" => "Setmanalment",
"Activity feed" => "Llista d'activitat",
"Personal activity feed for %s" => "Llista d'activitat personal per a %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
